@@ -25,7 +25,7 @@ def get_access_token() -> str:
 
     access_token = jwt.encode(access_token_layout, 'secret', algorithm='HS256',
                               headers={'kid': '230498151c214b788dd97f22b85410a5'})
-    return access_token.decode('utf-8')
+    return access_token
 
 @responses.activate
 def test_request_token_auth_default():
